---
name: Bug report
about: Create a report to help us improve
title: "[Bug] "
labels: Bug
---

### Description


### Steps to Reproduce

1. 
2. 
3. 

### Expected Behavior


### Actual Behavior


### Platforms

- [ ] Android
- [ ] iOS


### Basic Information

- Jakar.SettingsView:
- Xamarin.Forms:
- Android Support Library Version: <!-- if applicable -->
- iOS SDK Version: <!-- if applicable -->
- Affected Devices:


### Reproduction Link

<!-- Please upload or provide a link to a reproduction case -->


### Workaround

<!-- Did you find any workaround for this issue? This can unblock other people while waiting for this issue to be resolved -->


### Screenshots

<!-- If the issue is a visual issue, please include screenshots showing the problem if possible -->

